/**
 * reload 模块，使用该方法加载模块时
 * 都会重新加载，这样可以解决更新 Mock 后必须重启服务的问题
 */
const reload = require('require-reload')(require)
/**
 * BrowserSync 的中间件，用于拦截请求以及返回假数据
 * @returns {Function} 适用于 middleware 的函数
 */
module.exports = function() {
    return function(req, res, next) {
        const mocks = reload('../../config/mock').mocks
        const method = req.method.toLowerCase()
        if (mocks[method] && mocks[method][req.url]) {
            res.setHeader('Content-Type', 'application/json')
            res.end(JSON.stringify(mocks[method][req.url].template))
            return false
        }
        next()
    }
}
